@@ -105,11 +105,11 @@ class EventBus:
             _LOG.debug("No listeners for event type %s", event_class.__name__)
             return []
 
-        task_futures: List["asyncio.Future[asyncio.Task[Any]]"] = []
+        task_futures: "List[asyncio.Future[asyncio.Task[Any]]]" = []
         for listener in listeners:
             # Pass in a future on which the asyncio.Task will be set when the coro
             # has been scheduled on the loop.
-            fut: "asyncio.Future[asyncio.Task[Any]]" = asyncio.Future()
+            fut: "asyncio.Future[asyncio.Task[Any]]" = self._loop.create_future()
             task_futures.append(fut)
             # Run threadsafe in case we're firing events from interrupt callback threads
             create_unawaited_task_threadsafe(
