@@ -6,7 +6,7 @@ import time
 from statistics import mean
 from typing import Any, Dict, List, Optional, cast
 
-from ...types import ConfigType, SensorValueType
+from ...types import CerberusSchemaType, ConfigType, SensorValueType
 from . import GenericSensor
 
 REQUIREMENTS = ("RPi.GPIO",)
@@ -22,7 +22,7 @@ REQUIREMENTS = ("RPi.GPIO",)
 # duration trigger pulse
 PULSE = 0.00001
 # sonic speed/2
-SPEED_2 = 17015
+SPEED_2 = 34300 / 2
 
 
 class HCSR04:
@@ -31,7 +31,8 @@ class HCSR04:
     attached to the Raspberry Pi's GPIO pins.
     """
 
-    def __init__(self, gpio: Any, name: str, pin_echo: int, pin_trigger: int, burst: int):
+    def __init__(self, gpio: Any, name: str, pin_echo: int, pin_trigger: int, burst: int,
+                 **kwargs: Any):
         self.gpio = gpio
         self.name = name
         self.pin_echo = pin_echo
@@ -58,9 +59,7 @@ class HCSR04:
                 delta = time.time() - self.start
                 self.distance = delta * SPEED_2
 
-        self.gpio.add_event_detect(
-            self.pin_echo, self.gpio.BOTH, callback=measure_callback
-        )
+        self.gpio.add_event_detect(self.pin_echo, self.gpio.BOTH, callback=measure_callback)
 
     def pulse(self) -> None:
         """
@@ -89,9 +88,7 @@ class HCSR04:
             measurements.append(cast(float, self.distance))
             time.sleep(0.05)
         if not measurements:
-            raise RuntimeError(
-                "Unable to measure range on HC-SR04 sensor '%s'" % self.name
-            )
+            raise RuntimeError("Unable to measure range on HC-SR04 sensor '%s'" % self.name)
         return mean(measurements)
 
 
@@ -100,10 +97,22 @@ class Sensor(GenericSensor):
     Implementation of the sensor using Raspberry Pi on-board GPIO.
     """
 
-    SENSOR_CONFIG = {
-        "pin_echo": {"type": "integer", "required": True, "empty": False},
-        "pin_trigger": {"type": "integer", "required": True, "empty": False},
-        "burst": {"type": "integer", "required": True, "empty": False},
+    SENSOR_SCHEMA: CerberusSchemaType = {
+        "pin_echo": {
+            "type": "integer",
+            "required": True,
+            "empty": False
+        },
+        "pin_trigger": {
+            "type": "integer",
+            "required": True,
+            "empty": False
+        },
+        "burst": {
+            "type": "integer",
+            "required": True,
+            "empty": False
+        },
     }
 
     def setup_module(self) -> None:
@@ -116,7 +125,7 @@ class Sensor(GenericSensor):
         self.sensors: Dict[str, HCSR04] = {}
 
     def setup_sensor(self, sens_conf: ConfigType) -> None:
-        sensor = HCSR04(**sens_conf)
+        sensor = HCSR04(gpio=self.gpio, **sens_conf)
         self.sensors[sensor.name] = sensor
 
     def get_value(self, sens_conf: ConfigType) -> SensorValueType:
